package org.apache.bcel.generic;

import java.util.Objects;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/PUSH.class */
public final class PUSH implements CompoundInstruction, VariableLengthInstruction, InstructionConstants {
    private final Instruction instruction;

    public PUSH(ConstantPoolGen cp, boolean value) {
        Objects.requireNonNull(cp, "cp");
        this.instruction = InstructionConst.getInstruction(3 + (value ? 1 : 0));
    }

    public PUSH(ConstantPoolGen cp, Boolean value) {
        this(cp, value.booleanValue());
    }

    public PUSH(ConstantPoolGen cp, Character value) {
        this(cp, (int) value.charValue());
    }

    public PUSH(ConstantPoolGen cp, double value) {
        if (value == 0.0d) {
            this.instruction = InstructionConst.DCONST_0;
        } else if (value == 1.0d) {
            this.instruction = InstructionConst.DCONST_1;
        } else {
            this.instruction = new LDC2_W(cp.addDouble(value));
        }
    }

    public PUSH(ConstantPoolGen cp, float value) {
        if (value == 0.0d) {
            this.instruction = InstructionConst.FCONST_0;
            return;
        }
        if (value == 1.0d) {
            this.instruction = InstructionConst.FCONST_1;
        } else if (value == 2.0d) {
            this.instruction = InstructionConst.FCONST_2;
        } else {
            this.instruction = new LDC(cp.addFloat(value));
        }
    }

    public PUSH(ConstantPoolGen cp, int value) {
        if (value >= -1 && value <= 5) {
            this.instruction = InstructionConst.getInstruction(3 + value);
            return;
        }
        if (Instruction.isValidByte(value)) {
            this.instruction = new BIPUSH((byte) value);
        } else if (Instruction.isValidShort(value)) {
            this.instruction = new SIPUSH((short) value);
        } else {
            this.instruction = new LDC(cp.addInteger(value));
        }
    }

    public PUSH(ConstantPoolGen cp, long value) {
        if (value == 0) {
            this.instruction = InstructionConst.LCONST_0;
        } else if (value == 1) {
            this.instruction = InstructionConst.LCONST_1;
        } else {
            this.instruction = new LDC2_W(cp.addLong(value));
        }
    }

    public PUSH(ConstantPoolGen cp, Number value) {
        if ((value instanceof Integer) || (value instanceof Short) || (value instanceof Byte)) {
            this.instruction = new PUSH(cp, value.intValue()).instruction;
            return;
        }
        if (value instanceof Double) {
            this.instruction = new PUSH(cp, value.doubleValue()).instruction;
        } else if (value instanceof Float) {
            this.instruction = new PUSH(cp, value.floatValue()).instruction;
        } else {
            if (value instanceof Long) {
                this.instruction = new PUSH(cp, value.longValue()).instruction;
                return;
            }
            throw new ClassGenException("What's this: " + value);
        }
    }

    public PUSH(ConstantPoolGen cp, ObjectType value) {
        if (value == null) {
            this.instruction = InstructionConst.ACONST_NULL;
        } else {
            this.instruction = new LDC(cp.addClass(value));
        }
    }

    public PUSH(ConstantPoolGen cp, String value) {
        if (value == null) {
            this.instruction = InstructionConst.ACONST_NULL;
        } else {
            this.instruction = new LDC(cp.addString(value));
        }
    }

    public Instruction getInstruction() {
        return this.instruction;
    }

    @Override // org.apache.bcel.generic.CompoundInstruction
    public InstructionList getInstructionList() {
        return new InstructionList(this.instruction);
    }

    public String toString() {
        return this.instruction + " (PUSH)";
    }
}
